@@ -15,10 +15,11 @@
 from pythonic_fp.splitends.splitend import SplitEnd as SE
 from pythonic_fp.iterables.merging import concat
 
+
 class Test_SplitEnds:
     def test_mutate_returns_none(self) -> None:
         ps = SE(41)
-        assert ps.extend(1,2,3) is None  # type: ignore[func-returns-value]
+        assert ps.extend(1, 2, 3) is None  # type: ignore[func-returns-value]
 
     def test_wxtend_then_snip(self) -> None:
         s1 = SE(42)
@@ -39,7 +40,7 @@ class Test_SplitEnds:
 
     def test_splitend_extend_snip(self) -> None:
         s1 = SE(101)
-        s2 = SE(*range(0,2000))
+        s2 = SE(*range(0, 2000))
 
         assert len(s1) == 1
         assert len(s2) == 2000
@@ -49,7 +50,7 @@ class Test_SplitEnds:
         assert len(s1) == 2
         assert len(s2) == 1998
         assert s1.snip() == 42
-        assert s1.snip() == 101     # re-rooted
+        assert s1.snip() == 101  # re-rooted
         s1.extend(12, 13, 14)
         assert len(s1) == 4
         assert s1.snip() == 14
@@ -61,11 +62,18 @@ class Test_SplitEnds:
         assert len(s1) == 1
         assert s1.snip() == 101
         assert len(s1) == 1
-
+        assert s2.cut(3) == (1997, 1996, 1995)
+        assert s2.cut(1) == (1994,)
+        assert s2.cut(0) == ()
+        assert s2.cut() == tuple(range(1993, -1, -1))
+        assert len(s2) == 1
+        assert s2.cut(5) == (0,)
+        s2.extend(1, 2, 3, 4, 5)
+        assert s2.cut() == (5, 4, 3, 2, 1, 0)
 
     def test_SplitEnd_len(self) -> None:
-        s1: SE[int|None] = SE(None)
-        s2: SE[int|None] = SE(None, 42)
+        s1: SE[int | None] = SE(None)
+        s2: SE[int | None] = SE(None, 42)
 
         assert len(s1) == 1
         if s1:
@@ -84,13 +92,13 @@ class Test_SplitEnds:
         assert s2.snip() is None
         assert len(s2) == 1
 
-        s2001: SE[int] = SE(*range(1,2001))
+        s2001: SE[int] = SE(*range(1, 2001))
         if s2001:
             assert len(s2001) == 2000
         else:
             assert False
 
-        s3 = s2001.copy()
+        s3 = s2001.split()
         assert len(s3) == 2000
         assert s3 == s2001
         assert s3.snip() == 2000
@@ -109,19 +117,19 @@ class Test_SplitEnds:
     def test_iteration(self) -> None:
         giantSplitEnd: SE[str] = SE(' Fum', ' Fo', ' Fi', 'Fe')
         giantTalk = giantSplitEnd.snip()
-        assert giantTalk == "Fe"
+        assert giantTalk == 'Fe'
         for giantWord in giantSplitEnd:
             giantTalk += giantWord
         assert len(giantSplitEnd) == 3
         assert giantTalk == 'Fe Fi Fo Fum'
 
-        gSE = giantSplitEnd.copy()
+        gSE = giantSplitEnd.split()
         for ff in gSE:
             assert ff[0] in {' ', 'F'}
 
     def test_equality(self) -> None:
         s1 = SE(*range(3))
-        s2 = s1.copy()
+        s2 = s1.split()
         s2.extend(42)
         assert s1 is not s2
         assert s1 != s2
@@ -131,7 +139,7 @@ class Test_SplitEnds:
         assert s2.peak() == 2
 
         s3 = SE(*range(1, 10001))
-        s4 = s3.copy()
+        s4 = s3.split()
         assert s3 is not s4
         assert s3 == s4
 
@@ -141,24 +149,25 @@ class Test_SplitEnds:
         assert s3 == s4
         assert s3 is not s4
 
-        s5 = SE(1,2,3,4)
-        s6 = SE(1,2,3,42)
+        s5 = SE(1, 2, 3, 4)
+        s6 = SE(1, 2, 3, 42)
         assert s5 != s6
         for ii in range(10):
             s5.extend(ii)
             s6.extend(ii)
         assert s5 != s6
 
-        ducks: tuple[str, ...] = ("Huey", "Dewey")
+        ducks: tuple[str, ...] = ('Huey', 'Dewey')
         s7 = SE((), ducks)
         s8 = SE((), ducks)
-        s9 = s8.copy()
-        s9.extend(("Huey", "Dewey", "Louie"))
-        assert s7 == s8
+        s9 = s7.split()
+        s9.extend(('Huey', 'Dewey', 'Louie'))
+        assert s7 != s8  # even with the singleton ()
+        SE(()) is not SE(())  # same root values, different root nodes
         assert s7 != s9
         assert s7.peak() == s8.peak()
         assert s7.peak() != s9.peak()
-        ducks = ducks + ("Louie",)
+        ducks = ducks + ('Louie',)
         s7.extend(ducks)
         assert s7 != s8
         assert s7 == s9
@@ -171,7 +180,7 @@ class Test_SplitEnds:
         assert s7.peak() == s9.peak()
 
     def test_storing_Nones(self) -> None:
-        s0: SE[int|None] = SE(100)
+        s0: SE[int | None] = SE(100)
         s0.extend(None)
         s0.extend(42)
         s0.extend(None)
@@ -183,14 +192,14 @@ class Test_SplitEnds:
             s0.snip()
         assert not s0
 
-        s1: SE[int|None] = SE(None)
+        s1: SE[int | None] = SE(None)
         s1.extend(24)
-        s2 = s1.copy()
+        s2 = s1.split()
         s2.extend(42)
         s1.extend(42)
         assert s1 == s2
         assert len(s1) == len(s2) == 3
-        s3 = s2.copy()
+        s3 = s2.split()
         s3.extend(None)
         assert s3.peak() is None
         assert s3
@@ -202,19 +211,22 @@ class Test_SplitEnds:
         assert len(s3) == 1
         s3.extend(42)
         s4 = SE(None, 42)
-        assert s3 == s4
+        assert s3 != s4
+        assert s3.peak() == s4.peak()
 
     def test_reversing(self) -> None:
-        s1 = SE('a', 'b', 'c', 'd')
-        s2 = SE('d', 'c', 'b', 'a')
-        assert s1 != s2
-        assert s2 == SE(*iter(s1))
-        s0 = SE('z')
-        assert s0 == SE(*iter(s0))
+        t1 = ('a', 'b', 'c', 'd')
+        t2 = ('d', 'c', 'b', 'a')
+        s1 = SE(*t1)
+        s2 = SE(*t2)
+        t2 == tuple(s1)
+        t1 == tuple(s2)
         s3 = SE(*concat(iter(range(1, 100)), iter(range(98, 0, -1))))
         s4 = SE(*s3)
-        assert s3 == s4
-        assert s3 is not s4
+        assert tuple(s3) == tuple(s4)
+        s3 = SE(*concat(iter(range(1, 100))))
+        s4 = SE(*s3)
+        assert tuple(s3) != tuple(s4)
 
     def test_reversed(self) -> None:
         lf = [1.0, 2.0, 3.0, 4.0]
@@ -227,8 +239,8 @@ class Test_SplitEnds:
         s2 = SE(*lf)
         for x in s2:
             assert x == lf.pop()
-        assert len(lf) == 0       # test iteration gets all values
-        assert len(s2) == 4       # s2 not consumed
+        assert len(lf) == 0  # test iteration gets all values
+        assert len(s2) == 4  # s2 not consumed
 
     def test_fold(self) -> None:
         def cat_str(s1: str, s2: str) -> str:
@@ -243,7 +255,36 @@ class Test_SplitEnds:
         assert se_str.fold(cat_str) == 'edcb'
         assert se_str.rev_fold(cat_str) == 'bcde'
         assert se_str.fold(cat_str, 'f') == 'fedcb'
-        assert se_str.rev_fold(cat_str, 'a' ) == 'abcde'
+        assert se_str.rev_fold(cat_str, 'a') == 'abcde'
 
         assert se_ord.fold(cat_ord, 'f') == 'fedcb'
-        assert se_ord.rev_fold(cat_ord, 'a' ) == 'abcde'
+        assert se_ord.rev_fold(cat_ord, 'a') == 'abcde'
+
+    def test_identity(self) -> None:
+        def push_se[S](se: SE[S], d: S) -> SE[S]:
+            se.extend(d)
+            return se
+
+        def add2(x: int, y: int) -> int:
+            return x + y
+
+        def mult2[S](x: int, y: int) -> int:
+            return x * y
+
+        se5 = SE(1, 2, 3, 4, 5)
+
+        assert se5.peak() == 5
+     #  assert se5.root() == 1
+
+        assert se5.fold(add2) == 15
+        assert se5.fold(add2, 10) == 25
+        assert se5.fold(mult2) == 120
+        assert se5.fold(mult2, 10) == 1200
+        se_temp = se5.split()
+        se_temp.snip()
+        se5_rev = se_temp.fold(push_se, SE(se5.peak()))
+        assert tuple(se5_rev) == tuple(SE(5, 4, 3, 2, 1))  # new root
+        se5_rev_twin = SE(se5.root(), 4, 3, 2, 1)
+        assert se5.fold(add2) == 15
+        assert se5.fold(add2, 10) == 25
+
